Module oxi_luajit::function

source ·

Functions

  • Calls a function previously stored in the Lua registry via store.
  • Removes the function reference stored in the Lua registry
  • Stores a function in the Lua registry, returning its ref.