Function oxi_luajit::function::remove
source · pub fn remove(lua_ref: c_int)Expand description
Removes the function reference stored in the Lua registry
pub fn remove(lua_ref: c_int)Removes the function reference stored in the Lua registry