☰
oxi_luajit
0.4.0
Module function
Functions
In crate oxi_luajit
?
Module
oxi_luajit
::
function
source
·
[
−
]
Functions
call
Calls a function previously stored in the Lua registry via
store
.
remove
Removes the function reference stored in the Lua registry
store
Stores a function in the Lua registry, returning its ref.